namespace eval ::remind {
	variable config
	variable configlist

##############################
# ::remind::InitPlugin dir   #
# ---------------------------#
# Load proc of Remind Plugin #
##############################

proc InitPlugin { dir } {

	::plugins::RegisterPlugin remind
	source [file join $dir remind.tcl]
	::plugins::RegisterEvent remind new_conversation LastSentences

	array set ::remind::config [list nbline {10}]

	set ::remind::configlist [list [list str "Number of line displayed" nbline] ]

}

################################################
# ::remind::LastSentences event epvar          #
# -------------------------------------------- #
# Display the last sentences in the chatwindow #
################################################

proc LastSentences { event evpar } {

	global log_dir

	upvar 2 $evpar parameters
	set chatid $parameters(chatid)
	set email $parameters(usr_name)

	# Select the last logging file, and cancel the proc if there is no log file yet
	if { [file exists [file join ${log_dir} ${email}.log]] == 1 } {
		set id [open "[file join ${log_dir} ${email}.log]" r]
	} elseif {[::config::getKey logsbydate] == 1} {	
		set date [glob -nocomplain -types f [file join ${log_dir} * ${email}.log]]
		if { $date != ""} {
			set sorteddate_list [lsort -integer -decreasing $date]
			set id [open [lindex $sorteddate_list 0] r]
		} else {
			return
		}
	} else {
		return
	}

	fconfigure $id -encoding utf-8
	set logvar [read $id]
	close $id

	# Select the $nbline last lines
	set loglines [split $logvar "\n"]
	set nbline [expr int($::remind::config(nbline))]
	set begin [expr [llength $loglines] - $nbline]
	set loglines [lrange $loglines $begin end]

	set tagname "black"

	set font [lindex [::config::getGlobalKey basefont] 0]
	if { $font == "" } { set font "Helvetica"}		

	set fontformat [list "" "" ""]

	::amsn::WinWrite $chatid "\nLast sentences in the previous conversations with $email :" blue

	foreach line $loglines {

		# If the line doesn't begin with |"L
		if { [string range $line 0 2] != "\|\"L" } {
			::amsn::WinWrite $chatid "$line" $tagname $fontformat
		} else {

			set color [string range $line 3 5]

			switch $color {

				GRA { # If the line is a message...

					set aidx [string first "\|\"L" $line 16]

					set color2 [string range $line [expr $aidx + 3] [expr $aidx + 5]]

					switch $color2 {

					    ITA {

						# Check if the time must be displayed or not
						if { [::config::getKey showtimestamps] } {
							set tstamp [string range $line 6 15]
						} else {
							set tstamp ""
						}

						set aidx [string first "\|\"L" $line 19]
						set nick [string range $line 23 [expr $aidx - 3]]

						# Look at the style used in chatwindows
						switch [::config::getKey chatstyle] {
						    msn {::config::setKey customchatstyle "\$tstamp [trans says \$nick]:\n"}
						    irc {::config::setKey customchatstyle "\$tstamp <\$nick> "}
						    - { }
						}

						set customchat [string map {"\\" "\\\\" "\$" "\\\$" "\(" "\\\(" } [::config::getKey customchatstyle]]
						set customchat [string map { "\\\$nick" "\${nick}" "\\\$tstamp" "\${tstamp}" } $customchat]
						set customchat [subst -nocommands $customchat]

						# Look if there is a color information in the message
						if {[string index $line [expr $aidx + 3]] == "C"} {
							set color [string range $line [expr $aidx + 4] [expr $aidx + 9]]
							set fontformat [list "$font" "" "$color"]
							set tagname "user"
							set string [string range $line [expr $aidx + 10] end]
						} else {
							set fontformat [list "$font" "" ""]
							set tagname black
							set string [string range $line [expr $aidx + 6] end]
						}

						::amsn::WinWrite $chatid "\n$customchat" gray
						::amsn::WinWrite $chatid "$string" $tagname $fontformat
				
					    }

					    GRE { #... or a filetransfert
						
						set string "\n[string range $line [expr $aidx + 6] end]"
						set tagname green
						::amsn::WinWrite $chatid "$string" green

					    }

					    - { }

					}

				}

				RED { #If the line is an information (e.g. conversation closed)
					
					set string "\n[string range $line 6 end]"
					set tagname red
					::amsn::WinWrite $chatid "$string" red
				}

				- { }
			}

		}

	}

	::amsn::WinWrite $chatid "\n" black

	set win_name [::ChatWindow::For $chatid]
	${win_name}.f.out.text yview end

}

}